function stamagnitude = STAmagnitude(sig, win, overlap )
%STAmagnitude Compute the average magnitude of a signal
% s = STAmagnitude(sig, win, overlap)
% Calculate the sum of absolute values of a signal in successive windows.
%
% Input
% sig:    The input signal
% win:    The window that should be used
% overlap:The overlap in samples between successive frames
%
% Output
% stamagnitude: The average magnitude signal
% 
% Example:
% load('mtlb');
% y = mtlb;
% wHamm = hamming(300);
% m = STAmagnitude(y, wHamm, 299);
% plot(m)
%
% Copyright Nassos Katsamanis (CVSP), http://cvsp.cs.ntua.gr/nassos

winLen = length(win);

[sigFramed, lastFrame] = buffer(sig, winLen, overlap,'nodelay');
sigAbsWindowed = diag(sparse(win)) * abs(sigFramed);

stamagnitude = sum(sigAbsWindowed, 1);

