function zcross = STAzerocross(sig, win, overlap)
%STAZEROCROSS Calculate short-time average zerocrossing rate
% zcross = STAzerocross(sig, win, overlap)
% Calculate the sum of sign changes of a signal in successive windows,
% divided by the length of the window.
%
% Input
% sig:    The input signal
% win:    The window that should be used
% overlap:The overlap in samples between successive frames
%
% Output
% stamagnitude: The average zero crossings rate signal
% 
% Example:
% load('mtlb');
% y = mtlb;
% wHamm = hamming(300);
% z = STAzerocross(y, wHamm, 299);
% plot(z)
%
% Copyright Nassos Katsamanis (CVSP), http://cvsp.cs.ntua.gr/nassos

winLen = length(win);

sigdif = sign(sig(2:end))-sign(sig(1:end-1));

% No change of sign at the beginning
sigdif = [0; sigdif];

[sigdifFramed, lastFrame] = buffer(sigdif, winLen, overlap,'nodelay');
sigdifWindowed = diag(sparse(win)) * abs(sigdifFramed);

zcross = sum(sigdifWindowed, 1) / (2*winLen);