function senergy = STenergy(sig, win, overlap )
%STENERGY Compute the Short-Time Energy of a signal
% Description
% s = STenergy(sig, win, overlap)
% Calculate the sum of squares of a signal in successive windows.
%
% Input
% sig:    The input signal
% win:    The window that should be used
% overlap:The overlap in samples between successive frames
%
% Output
% senergy: The short-time energy signal
% 
% Example:
% load('mtlb');
% y = mtlb;
% wHamm = hamming(300);
% s = STenergy(y, wHamm, 299);
% plot(s)
%
% Copyright Nassos Katsamanis (CVSP), http://cvsp.cs.ntua.gr/nassos

winLen = length(win);

% Framing the signal without for loops
[sigFramed, lastFrame] = buffer(sig, winLen, overlap, 'nodelay');
sigWindowed = diag(sparse(win)) * sigFramed;

senergy = sum(sigWindowed.^2,1);
