function data = readdata(path, delimiter, appear, name)
%READDATA Read data from files with structured filenames
% data = readdata(path, delimiter, appear, name)
% Read the files in the directory path and by means of their structured
% filenames try to organize the data in a struct. The function has been
% used to read files containing phonemes in binary format. The names of the
% files contained info relative to the speaker, the bounds in the sentence
% and the phoneme tag. The delimiter was an underscore (_).
% Input
% path :       The path of the directory that contains the files
% delimiter:   Delimiter between different tags contained in the filename
% appear:      The position of the info we want to extract from the 
%              filename in this filename, taking the delimiters into consideration
% name:        A name for the resulting struct, to indicate its use probably
%
% Output:
% data:        Structure containing the data from the files
%
% Copyright Nassos Katsamanis (CVSP), http://cvsp.cs.ntua.gr/nassos
files = dir(path);
data.name = name;

for k = 1:length(files)
    if ~files(k).isdir % Ignore subdirectories
        signal = readdatafile([path,'/',files(k).name]);
        toks = strread(files(k).name,'%s','delimiter',delimiter);
        if ~strmatch(toks{1},files(k).name) % Ignore files with differently structured filenames
            lab = toks{appear};
            if isfield(data, lab)
                s = getfield(data, lab);
                s{end+1} = signal;
                data.(lab) = s;
            else
                data.(lab) = {signal};
            end
        end
    end
end
    
    